@@ -1,6 +1,26 @@
 # -*- coding:utf-8; tab-width:4; mode:python -*-
 
+# doublex
+#
+# Copyright © 2012 David Villa Alises
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+
 import itertools
+import threading
 
 import hamcrest
 from hamcrest.core.base_matcher import BaseMatcher
@@ -73,11 +93,13 @@ class Method(Observable):
         super(Method, self).__init__()
         self.double = double
         self.name = name
+        self.event = threading.Event()
 
     def __call__(self, *args, **kargs):
         if not self.double._setting_up:
             self.notify(*args, **kargs)
 
+        self.event.set()
         invocation = self.create_invocation(args, kargs)
         return self.double._manage_invocation(invocation)
 
