@@ -1,5 +1,24 @@
 # -*- coding:utf-8; tab-width:4; mode:python -*-
 
+# doublex
+#
+# Copyright © 2012 David Villa Alises
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+
 import hamcrest
 from hamcrest.core.base_matcher import BaseMatcher
 from hamcrest import assert_that, is_
@@ -25,10 +44,14 @@ class MethodCalled(OperationMatcher):
     def __init__(self, context=None, times=any_time):
         self.context = context or InvocationContext(ANY_ARG)
         self._times = times
+        self._async_timeout = None
 
     def _matches(self, method):
         self._assure_is_spied_method(method)
         self.method = method
+        if self._async_timeout:
+            method.event.wait(self._async_timeout)
+
         return method._was_called(self.context, self._times)
 
     def _assure_is_spied_method(self, method):
@@ -50,6 +73,10 @@ class MethodCalled(OperationMatcher):
         self.context.update_args(args, kargs)
         return self
 
+    def async(self, timeout):
+        self._async_timeout = timeout
+        return self
+
     def times(self, n):
         self._times = n
         return self
